@@ -1,6 +1,7 @@
 from gevent import monkey; monkey.patch_all()
 from utils import CachedData
 from Corellia.taskqueue import TaskQueue
+import time
 
 class Worker(object):
     def __init__(self, addr, path, **kargs):
@@ -8,8 +9,8 @@ class Worker(object):
 
     def run(self, cls, *args, **kargs):
         ins = cls(*args, **kargs)
-        print ins
         while 1:
+            print "wait", time.clock()
             task =  self.tq.GET_TASK()
             key, method, args = task
             func = getattr(ins, method, None)
@@ -20,7 +21,8 @@ class Worker(object):
                 #   result = str(e)
             else:
                 result = "No Such Method!"
-            self.tq.PUT_RESULT(key, result) 
+            self.tq.PUT_RESULT(key, result)
+            print "send", time.clock()
 
 
 class Runtime(object):
